@@ -7,7 +7,7 @@ import hail as hl
 import hailtop.batch as hb
 
 
-def init_query_service():
+def init_batch():
     """Initializes the Hail Query Service from within Hail Batch.
 
     Requires the HAIL_BILLING_PROJECT and HAIL_BUCKET environment variables to be set."""
@@ -15,7 +15,7 @@ def init_query_service():
     billing_project = os.getenv('HAIL_BILLING_PROJECT')
     assert billing_project
     return asyncio.get_event_loop().run_until_complete(
-        hl.init_service(
+        hl.init_batch(
             default_reference='GRCh38',
             billing_project=billing_project,
             remote_tmpdir=remote_tmpdir(),
@@ -41,8 +41,6 @@ def copy_common_env(job: hb.job.Job) -> None:
         'CPG_OUTPUT_PREFIX',
         'HAIL_BILLING_PROJECT',
         'HAIL_BUCKET',
-        'HAIL_JAR_URL',
-        'HAIL_SHA',
     ):
         val = os.getenv(key)
         if val:
